OC.L10N.register(
    "settings",
    {
    "Migration in progress. Please wait until the migration is finished" : "이전 작업 중입니다. 작업이 완료될 때까지 기다려 주십시오",
    "Migration started …" : "이전 시작됨...",
    "Saved" : "저장됨",
    "Not saved" : "저장하지 않음",
    "Sending…" : "보내는 중…",
    "Email sent" : "이메일 보냄",
    "An error occurred. Please upload an ASCII-encoded PEM certificate." : "오류가 발생했습니다. ASCII로 인코딩된 PEM 인증서를 업로드하십시오.",
    "Valid until {date}" : "{date}까지 유효함",
    "Delete" : "삭제",
    "Local" : "로컬",
    "Private" : "개인",
    "Only visible to local users" : "로컬 사용자만 보임",
    "Only visible to you" : "나만 보임",
    "Contacts" : "연락처",
    "Visible to local users and to trusted servers" : "로컬 사용자와 신뢰된 서버에게 보이기",
    "Public" : "공개",
    "Will be synced to a global and public address book" : "공개 및 전역 주소록으로 동기화됨",
    "Verify" : "확인",
    "Verifying …" : "확인 중 …",
    "Unable to change password" : "암호를 변경할 수 없음",
    "Very weak password" : "매우 약한 암호",
    "Weak password" : "약한 암호",
    "So-so password" : "그저 그런 암호",
    "Good password" : "좋은 암호",
    "Strong password" : "강력한 암호",
    "An error occurred while changing your language. Please reload the page and try again." : "언어를 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
    "An error occurred while changing your locale. Please reload the page and try again." : "지역을 변경하는 중 오류가 발생했습니다. 페이지를 새로 고친 후 다시 시도하십시오.",
    "Select a profile picture" : "프로필 사진 선택",
    "Groups" : "그룹",
    "Group list is empty" : "그룹 목록이 비었음",
    "Unable to retrieve the group list" : "그룹 목록을 받아올 수 없음",
    "{actor} added you to group {group}" : "{actor} 가 당신을 {group} 그룹에 추가했습니다.",
    "You added {user} to group {group}" : "당신은 {user}를 {group} 그룹에 추가했습니다.",
    "{actor} added {user} to group {group}" : "{actor} 가 {user}를 {group} 그룹에 추가했습니다.",
    "An administrator added you to group {group}" : "관리자가 당신을 {group} 그룹에 추가했습니다.",
    "An administrator added {user} to group {group}" : "관리자가 {user}를 {group} 그룹에 추가했습니다.",
    "{actor} removed you from group {group}" : "{actor}가 당신을 {group} 그룹에서 삭제했습니다.",
    "You removed {user} from group {group}" : "당신이 {user}를 {group} 그룹에서 삭제했습니다.",
    "{actor} removed {user} from group {group}" : "{actor}가 {user}를 {group} 그룹에서 삭제했습니다.",
    "An administrator removed you from group {group}" : "관리자가 당신을 {group} 그룹에서 삭제했습니다.",
    "An administrator removed {user} from group {group}" : "관리자가 {user}를 {group} 그룹에서 삭제했습니다.",
    "Your <strong>group memberships</strong> were modified" : "당신의 <strong>그룹 멤버십</strong>이 수정되었습니다.",
    "{actor} changed your password" : "{actor} 님이 내 암호를 변경함",
    "You changed your password" : "내 암호를 변경함",
    "Your password was reset by an administrator" : "관리자가 내 암호를 초기화함",
    "{actor} changed your email address" : "{actor} 님이 내 이메일 주소를 변경함",
    "You changed your email address" : "내 이메일 주소를 변경함",
    "Your email address was changed by an administrator" : "관리자가 내 이메일 주소를 변경함",
    "You created app password \"{token}\"" : "앱 패스워드 \"{token}\"이 생성되었습니다.",
    "You deleted app password \"{token}\"" : "앱 패스워드 \"{token}\"이 제거되었습니다.",
    "You renamed app password \"{token}\" to \"{newToken}\"" : "앱 패스워드 \"{token}\"의 이름을 \"{newToken}\"으로 바꿨습니다.",
    "Security" : "보안",
    "You successfully logged in using two-factor authentication (%1$s)" : "2단계 인증으로 로그인함(%1$s)",
    "A login attempt using two-factor authentication failed (%1$s)" : "2단계 인증 시도가 실패함(%1$s)",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "내 <strong>암호</strong> 및 <strong>이메일</strong>이 변경됨",
    "Couldn't remove app." : "앱을 삭제할 수 없습니다.",
    "Couldn't update app." : "앱을 업데이트할 수 없습니다.",
    "Wrong password" : "잘못된 암호",
    "No user supplied" : "사용자가 지정되지 않음",
    "Authentication error" : "인증 오류",
    "Please provide an admin recovery password; otherwise, all user data will be lost." : "관리자 복구 암호를 입력하십시오. 그렇지 않으면 모든 사용자 데이이터가 초기화됩니다다.",
    "Wrong admin recovery password. Please check the password and try again." : "관리자 복구 암호가 잘못되었습니다. 암호를 다시 확인하십시오.",
    "Backend doesn't support password change, but the user's encryption key was updated." : "백엔드에서 암호 변경을 지원하지 않지만 사용자의 암호화 키는 업데이트되었습니다.",
    "installing and updating apps via the app store or Federated Cloud Sharing" : "앱 스토어 및 연합 클라우드 공유로 앱 설치 및 업데이트",
    "Federated Cloud Sharing" : "클라우드 연합 공유",
    "Invalid SMTP password." : "SMTP 암호가 잘못되었습니다.",
    "Email setting test" : "이메일 설정 시험",
    "Well done, %s!" : "%s 님, 잘 하셨습니다!",
    "If you received this email, the email configuration seems to be correct." : "이 이메일을 받으셨다면 이메일 설정이 올바릅니다.",
    "Email could not be sent. Check your mail server log" : "이메일을 보낼 수 없습니다. 메일 서버 로그를 확인하십시오.",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "이메일을 보내는 중 오류가 발생했습니다. 설정을 확인하십시오.(오류: %s)",
    "You need to set your user email before being able to send test emails." : "테스트 이메일을 보내기 전 내 주소를 설정해야 합니다.",
    "Invalid mail address" : "잘못된 이메일 주소",
    "Settings saved" : "설정 저장됨",
    "Unable to change full name" : "전체 이름을 변경할 수 없음",
    "Unable to change email address" : "이메일 주소를 변경할 수 없음",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "내 트위터 계정을 확인하려면 다음 트윗을 타임라인에 게시하십시오(줄바꿈을 추가하지 마십시오):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "내 웹 사이트를 확인하려면 다음 내용을 웹 사이트 루트 디렉터리의 '.well-known/CloudIdVerificationCode.txt' 파일에 게시하십시오(전체 텍스트가 한 줄에 들어가야 함):",
    "%1$s changed your password on %2$s." : "%1$s 님이 내 암호를 %2$s에 변경했습니다.",
    "Your password on %s was changed." : "내 %s 암호를 변경했습니다.",
    "Your password on %s was reset by an administrator." : "관리자가 내 %s 암호를 초기화했습니다.",
    "Password for %1$s changed on %2$s" : "%1$s의 암호를 %2$s에 변경함",
    "Password changed for %s" : "%s의 암호 변경됨",
    "If you did not request this, please contact an administrator." : "요청하지 않았다면 관리자에게 연락하십시오.",
    "Your email address on %s was changed." : "내 %s 이메일 주소를 변경했습니다.",
    "Your email address on %s was changed by an administrator." : "관리자가 내 %s 이메일 주소를 변경했습니다.",
    "Email address for %1$s changed on %2$s" : "%1$s의 이메일 주소를 %2$s에 변경함",
    "Email address changed for %s" : "%s의 이메일 주소 변경됨",
    "The new email address is %s" : "새 이메일 주소는 %s입니다",
    "Your %s account was created" : "%s 계정을 등록했습니다",
    "Welcome aboard" : "환영합니다",
    "Welcome aboard %s" : "%s 님, 환영합니다",
    "Welcome to your %s account, you can add, protect, and share your data." : "%s 계정에 오신 것을 환영합니다. 데이터를 추가, 보호, 공유할 수 있습니다.",
    "Your username is: %s" : "사용자 이름: %s",
    "Set your password" : "내 암호 설정하기",
    "Go to %s" : "%s(으)로 이동",
    "Install Client" : "클라이언트 설치",
    "Create" : "생성",
    "Change" : "변경",
    "Share" : "공유",
    "Unlimited" : "무제한",
    "Verifying" : "검사",
    "Two-factor authentication can be enforced for all\tusers and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "2단계 인증을 모든 유저 또는 특정 그룹에 강제할 수 있습니다. 만약 대상자가 2단계 인증 공급자를 설정하지 않았다면, 대상자는 시스템에 접근할 수 없게 될 것입니다.",
    "Enforce two-factor authentication" : "2단계 인증 강제하기",
    "Limit to groups" : "그룹으로 제한",
    "Enforcement of two-factor authentication can be set for certain groups only." : "2단계 인증 강제는 특정 그룹에게만 적용됩니다.",
    "Two-factor authentication is enforced for all\tmembers of the following groups." : "2단계 인증이 모든 멤버에게 강제된 그룹은\t다음과 같습니다.",
    "Enforced groups" : "강제된 그룹",
    "Two-factor authentication is not enforced for\tmembers of the following groups." : "2단계 인증이 강제되지 않은 그룹은\t다음과 같습니다.",
    "Excluded groups" : "제외된 그룹",
    "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "그룹이 선택되거나 제외되었을 때, 다음과 같은 상황을 고려할 수 있습니다. 만약 2단계 인증이 강제되었고, 아무런 그룹이 선택되지 않았다면 제외된 그룹의 멤버를 제외하고 모든 유저에게 2단계 인증이 강제됩니다. 만약 그룹이 선택되었다면 그룹 안의 모든 멤버에게 2단계 인증이 강제됩니다. 만약 유저가 선택된 그룹과 제외된 그룹에 동시에 속해있다면, 선택된 그룹이 우선되며 2단계 인증이 강제됩니다.",
    "Save changes" : "변경 사항 저장",
    "Official apps are developed by and within the community. They offer central functionality and are ready for production use." : "커뮤니티가 개발한 공식 앱입니다. 이 앱은 Nextcloud의 핵심 기능이며 프로덕션 환경에서 사용할 수 있습니다.",
    "Official" : "공식",
    "Remove" : "삭제",
    "Disable" : "사용 안함",
    "All" : "모두",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최소 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "이 앱은 Nextcloud 최대 버전을 지정하지 않았습니다. 차후 버전에서는 오류로 처리됩니다.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "다음 의존성을 만족할 수 없기 때문에 이 앱을 설치할 수 없습니다:",
    "View in store" : "스토어에서 보기",
    "Visit website" : "웹 사이트 방문",
    "Report a bug" : "버그 신고",
    "User documentation" : "사용자 문서",
    "Admin documentation" : "관리 문서",
    "Developer documentation" : "개발자 문서",
    "No apps found for your version" : "설치된 버전에 대한 앱 없음",
    "Enable all" : "모두 활성화",
    "Enable" : "사용함",
    "The app will be downloaded from the app store" : "이 앱을 앱 스토어에서 다운로드합니다",
    "Device settings" : "디바이스 설정",
    "Allow filesystem access" : "파일시스템 접근 허용",
    "Rename" : "이름 바꾸기",
    "Revoke" : "취소",
    "Wipe device" : "디바이스 지우기",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google 크롬",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Android용 Google 크롬",
    "Sync client - {os}" : "동기화 클라이언트 - {os}",
    "This session" : "이 세션",
    "Device" : "장치",
    "Last activity" : "최근 활동",
    "Web, desktop and mobile clients currently logged in to your account." : "사용자 계정으로 로그인된 웹, 데스크톱, 모바일 클라이언트 목록입니다.",
    "Error while creating device token" : "장치 토큰을 만드는 중 오류가 발생했습니다",
    "Error while deleting the token" : "토큰을 삭제하는 중 오류가 발생했습니다",
    "App name" : "앱 이름",
    "Create new app password" : "새로운 앱 암호 만들기",
    "Use the credentials below to configure your app or device." : "앱 또는 장치를 구성하는 아래의 자격 증명을 사용합니다.",
    "For security reasons this password will only be shown once." : "보안상의 이유로 이 암호는 한 번만 표시됩니다.",
    "Username" : "사용자 이름",
    "Password" : "암호",
    "Done" : "완료",
    "Copied!" : "복사 성공!",
    "Copy" : "복사",
    "New password" : "새 암호",
    "Never" : "하지 않음",
    "Delete user" : "유저 지우기",
    "Disable user" : "유저 비활성화하기",
    "Enable user" : "유저 활성화하기",
    "Resend welcome email" : "환영 메일 다시 보내기",
    "{size} used" : "{size} 사용됨",
    "Welcome mail sent!" : "환영 메일을 보냈습니다!",
    "Display name" : "표시 이름",
    "Email" : "이메일",
    "Group admin for" : "다음 그룹의 관리자:",
    "Quota" : "할당량",
    "Language" : "언어",
    "Storage location" : "저장소 위치",
    "User backend" : "사용자 백엔드",
    "Last login" : "마지막 로그인",
    "Default language" : "기본 언어",
    "Add a new user" : "새 사용자 추가",
    "No users in here" : "사용자가 이곳에 없습니다.",
    "Default quota" : "기본 할당량",
    "All languages" : "모든 언어",
    "Your apps" : "내 앱",
    "Active apps" : "활성화된 앱",
    "Disabled apps" : "비활성화된 앱",
    "Updates" : "업데이트",
    "App bundles" : "앱 번들",
    "New user" : "새 사용자",
    "Default quota:" : "기본 할당량:",
    "Select default quota" : "기본 할당량 설정",
    "Show Languages" : "언어 보이기",
    "Show last login" : "마지막 로그인 보이기",
    "Show user backend" : "사용자 백엔드 보이기",
    "Show storage path" : "스토리지 경로 보이기",
    "Remove group" : "그룹 지우기",
    "Admins" : "관리자",
    "Disabled users" : "비활성화된 유저",
    "Everyone" : "모두",
    "Add group" : "그룹 추가",
    "You are about to remove the group {group}. The users will NOT be deleted." : "당신은 {group} 그룹을 지우려고 합니다. 그룹의 사용자들은 삭제되지 않습니다.",
    "Please confirm the group removal " : "그룹 지우기를 확인해주세요.",
    "An error occured during the request. Unable to proceed." : "요청을 보내는 도중 에러가 발생하였습니다. 더 이상 진행할 수 없습니다.",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "앱이 활성화되었지만, 앱을 업데이트해야 합니다. 5초 후 앱 업데이트 페이지로 넘어갑니다.",
    "App update" : "앱 업데이트",
    "Error: This app can not be enabled because it makes the server unstable" : "오류: 이 앱은 서버를 불안정하게 만들 수 있어서 활성화할 수 없습니다",
    "SSL Root Certificates" : "SSL 루트 인증서",
    "Common Name" : "공통 이름",
    "Valid until" : "만료 기간:",
    "Issued By" : "발급자:",
    "Valid until %s" : "%s까지 유효함",
    "Import root certificate" : "루트 인증서 가져오기",
    "Administrator documentation" : "관리자 문서",
    "Documentation" : "문서",
    "Forum" : "포럼",
    "None" : "없음",
    "Login" : "로그인",
    "Plain" : "일반",
    "NT LAN Manager" : "NT LAN 관리자",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "Email server" : "이메일 서버",
    "Open documentation" : "문서 열기",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "암호 초기화 및 알림 이메일을 보내려면 이메일 서버를 설정해야 합니다.",
    "Send mode" : "보내기 모드",
    "Encryption" : "암호화",
    "Sendmail mode" : "Sendmail 모드",
    "From address" : "보낸 사람 주소",
    "mail" : "메일",
    "Authentication method" : "인증 방법",
    "Authentication required" : "인증 필요함",
    "Server address" : "서버 주소",
    "Port" : "포트",
    "Credentials" : "인증 정보",
    "SMTP Username" : "SMTP 사용자 이름",
    "SMTP Password" : "SMTP 암호",
    "Test email settings" : "이메일 설정 시험",
    "Send email" : "이메일 보내기",
    "Security & setup warnings" : "보안 및 설치 경고",
    "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "당신의 인스턴스의 보안과 성능을 위해서는 모든 것이 정확하게 설정되어야 합니다. 그러기 위해서 자동적으로 몇 가지를 확인하겠습니다. 더 자세한 정보를 위해서 링크된 문서를 참고하세요.",
    "All checks passed." : "모든 검사를 통과했습니다.",
    "There are some errors regarding your setup." : "설정을 살펴본 결과 몇 가지 에러가 있습니다.",
    "There are some warnings regarding your setup." : "설정을 살펴본 결과 몇 가지 경고할 것이 있습니다.",
    "Checking for system and security issues." : "시스템과 보안에 대한 문제를 확인하는 중",
    "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">우리의 보안 검사 ↗</a>에서 당신의 Nextcloud의 보안을 점검하세요.",
    "Version" : "버전",
    "Two-Factor Authentication" : "2단계 인증",
    "Server-side encryption" : "서버 측 암호화",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "서버 측 암호화를 사용하면 이 서버에 업로드되는 파일을 암호화할 수 있습니다. 성능 감소 등 제약 사항이 있으므로 필요한 경우에만 사용하십시오.",
    "Enable server-side encryption" : "서버 측 암호화 사용",
    "Please read carefully before activating server-side encryption: " : "서버 측 암호화를 활성화하기 전에 읽어 보십시오:",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "암호화를 사용하면, 사용하기 시작한 시간 이후에 서버에 업로드된 모든 파일이 암호화됩니다. 나중에 암호화를 사용하지 않으려면 사용하고 있는 암호화 모듈에서 비활성화를 지원해야 하고 모든 사전 조건(예: 복구 키 설정)을 만족해야 합니다.",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "암호화만으로 시스템의 보안을 보장할 수 없습니다. 암호화 응용 프로그램 작동 방식 및 지원되는 사용 사례에 대한 자세한 내용은 설명서를 참조하십시오.",
    "Be aware that encryption always increases the file size." : "암호화된 파일의 크기는 항상 커집니다.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "데이터를 주기적으로 백업하는 것을 추천하며, 암호화를 사용하고 있다면 데이터와 더불어 암호화 키도 백업하십시오.",
    "This is the final warning: Do you really want to enable encryption?" : "마지막 경고입니다. 암호화를 활성화하시겠습니까?",
    "Enable encryption" : "암호화 사용",
    "No encryption module loaded, please enable an encryption module in the app menu." : "암호화 모듈을 불러오지 않았습니다. 앱 메뉴에서 암호화 모듈을 활성화하십시오.",
    "Select default encryption module:" : "기본 암호화 모듈 선택:",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "과거에 사용하였던(ownCloud <= 8.0) 암호화된 데이터에서 키를 이전해야 합니다. \"기본 암호화 모듈\"을 활성화한 다음 'occ encryption:migrate'를 실행하십시오",
    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "ownCloud 8.0 이하에서 사용한 이전 암호화 키를 새 키로 이전해야 합니다.",
    "Start migration" : "이전 시작",
    "Background jobs" : "배경 작업",
    "Last job ran %s." : "마지막 작업이 %s에 실행되었습니다.",
    "Last job execution ran %s. Something seems wrong." : "마지막 작업이 %s에 실행되었습니다. 무언가 잘못된 것 같습니다.",
    "Background job didn’t run yet!" : "배경 작업이 아직 실행되지 않았습니다!",
    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "최적 성능을 위해서 백그라운드 작업을 올바르게 설정하는 것을 추천합니다. 큰 인스턴스에서는 'Cron'을 사용하는 것을 추천합니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
    "Execute one task with each page loaded" : "개별 페이지를 불러올 때마다 실행",
    "The cron.php needs to be executed by the system user \"%s\"." : "시스템 사용자 \"%s\"(으)로 cron.php를 실행해야 합니다.",
    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "이 항목을 실행하려면 PHP POSIX 확장이 필요합니다. 자세한 사항은 {linkstart}PHP 문서{linkend}를 참조하십시오.",
    "Sharing" : "공유",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "관리자로 공유 행동을 미세 조정할 수 있습니다. 더 많은 정보를 보려면 문서를 참조하십시오.",
    "Allow apps to use the Share API" : "앱에서 공유 API를 사용할 수 있도록 허용",
    "Allow users to share via link" : "사용자별 링크 공유 허용",
    "Allow public uploads" : "공개 업로드 허용",
    "Always ask for a password" : "항상 암호 묻기",
    "Enforce password protection" : "암호 보호 강제",
    "Set default expiration date" : "기본 만료 날짜 설정",
    "Expire after " : "다음 날짜 후 만료",
    "days" : "일",
    "Enforce expiration date" : "만료 날짜 강제",
    "Allow resharing" : "재공유 허용",
    "Allow sharing with groups" : "그룹과 공유 허용",
    "Restrict users to only share with users in their groups" : "그룹 내 사용자끼리만 공유할 수 있도록 허용",
    "Exclude groups from sharing" : "공유에서 그룹 제외",
    "These groups will still be able to receive shares, but not to initiate them." : "이 그룹의 사용자들은 다른 사용자가 공유한 파일을 받을 수는 있지만, 자기 파일을 공유할 수는 없습니다.",
    "Allow username autocompletion in share dialog. If this is disabled the full username or email address needs to be entered." : "공유 대화 상자에서 사용자 이름을 자동으로 완성합니다. 이 설정을 사용하지 않으면 전체 사용자 이름이나 이메일 주소를 입력해야 합니다.",
    "Show disclaimer text on the public link upload page. (Only shown when the file list is hidden.)" : "공개 링크 업로드 페이지에 고지 사항 텍스트를 표시합니다.(파일 목록이 숨겨져 있는 경우에만 표시합니다.)",
    "This text will be shown on the public link upload page when the file list is hidden." : "파일 목록이 숨겨져 있으면 이 텍스트는 공개 링크 업로드 페이지에 표시됩니다.",
    "Personal" : "개인",
    "Administration" : "관리",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "{communityopen}Nextcloud 커뮤니티{linkclose}에서 개발, {githubopen}소스 코드{linkclose}는 {licenseopen}<abbr title=\"Affero General Public License\">AGPL</abbr>{linkclose} 라이선스를 따릅니다.",
    "Like our Facebook page" : "Facebook 페이지에서 좋아요 누르기",
    "Follow us on Twitter" : "트위터에서 팔로하기",
    "Check out our blog" : "블로그 확인하기",
    "Subscribe to our newsletter" : "뉴스레터 구독하기",
    "Profile picture" : "프로필 사진",
    "Upload new" : "새로 업로드",
    "Select from Files" : "파일에서 선택",
    "Remove image" : "그림 삭제",
    "png or jpg, max. 20 MB" : "PNG, JPG, 최대 20MB",
    "Picture provided by original account" : "원래 계정에서 제공하는 사진",
    "Cancel" : "취소",
    "Choose as profile picture" : "프로필 사진으로 선택",
    "Details" : "자세히",
    "You are a member of the following groups:" : "당신은 다음 그룹의 멤버입니다:",
    "You are using <strong>%s</strong>" : "현재 <strong>%s</strong>를 사용하고 있습니다.",
    "You are using <strong>%1$s</strong> of <strong>%2$s</strong> (<strong>%3$s %%</strong>)" : "현재 <strong>%2$s</strong> /%1$s</strong>(<strong>%3$s%%</strong>)를 사용하고 있습니다",
    "Full name" : "전체 이름",
    "No display name set" : "표시 이름이 설정되지 않음",
    "Your email address" : "이메일 주소",
    "No email address set" : "이메일 주소가 설정되지 않음",
    "For password reset and notifications" : "암호 초기화 및 알림에 사용",
    "Phone number" : "휴대폰 번호",
    "Your phone number" : "내 휴대폰 번호",
    "Address" : "주소",
    "Your postal address" : "내 우편 주소",
    "Website" : "웹사이트",
    "It can take up to 24 hours before the account is displayed as verified." : "계정이 확인된 것으로 표시될 때까지 최대 24시간이 걸릴 수 있습니다",
    "Link https://…" : "링크 https://…",
    "Twitter" : "트위터",
    "Twitter handle @…" : "트위터 핸들 @…",
    "Help translate" : "번역 돕기",
    "Locale" : "지역",
    "Current password" : "현재 암호",
    "Change password" : "암호 변경",
    "Use a second factor besides your password to increase security for your account." : "사용자의 계정을 더욱 안전하게 보호하기 위해 암호와 함께 2단계 인증을 사용하세요.",
    "Disconnect" : "연결 해제",
    "Not supported!" : "지원되지 않습니다!",
    "Press Ctrl-C to copy." : "복사하기 위해 Ctrl-C를 누르세요.",
    "Store credentials" : "인증 정보 저장",
    "cron.php is registered at a webcron service to call cron.php every 15 minutes over HTTP." : "15분마다 HTTP를 통해 cron.php를 실행하는 webcron 서비스에 cron.php가 등록되었습니다.",
    "Use system cron service to call the cron.php file every 15 minutes." : "시스템 cron 서비스를 통해 15분마다 cron.php 파일을 실행합니다."
},
"nplurals=1; plural=0;");
